@@ -17,6 +17,14 @@ from .entity import (
     InstanceInfo,
     InstanceUserSetting,
     NodeInventory,
+    OpenaiChatChoice,
+    OpenaiChatInput,
+    OpenaiChatMessage,
+    OpenaiChatOutput,
+    OpenaiChatUsage,
+    OpenaiItem,
+    OpenaiRequest,
+    OpenaiResponse,
     ProxyInfo,
     RandomTemplateVariables,
     RecoverSetting,
@@ -45,6 +53,14 @@ from .dto import (
     InstanceInfoDTO,
     InstanceUserSettingDTO,
     NodeInventoryDTO,
+    OpenaiChatChoiceDTO,
+    OpenaiChatInputDTO,
+    OpenaiChatMessageDTO,
+    OpenaiChatOutputDTO,
+    OpenaiChatUsageDTO,
+    OpenaiItemDTO,
+    OpenaiRequestDTO,
+    OpenaiResponseDTO,
     ProxyInfoDTO,
     RandomTemplateVariablesDTO,
     RecoverSettingDTO,
@@ -674,3 +690,179 @@ class InstanceCreationItemAssembler(Assembler):
             _life_time = x._life_time.get_value()
         )
 instance_creation_item_assembler=InstanceCreationItemAssembler()
+
+
+
+class OpenaiChatMessageAssembler(Assembler):
+    def to_entity(self, dto: OpenaiChatMessageDTO):
+        return OpenaiChatMessage(
+            content = UStr(dto.content),
+            role = UStr(dto.role)
+        )
+    def to_dto(self, x:OpenaiChatMessage):
+        return OpenaiChatMessageDTO(
+            content = x.content.get_value(),
+            role = x.role.get_value()
+        )
+openai_chat_message_assembler=OpenaiChatMessageAssembler()
+
+
+
+class OpenaiChatInputAssembler(Assembler):
+    def to_entity(self, dto: OpenaiChatInputDTO):
+        return OpenaiChatInput(
+            messages = [openai_chat_message_assembler.to_entity(m) for m in dto.messages],
+            model = UStr(dto.model),
+            temperature = UInt(dto.temperature),
+            top_p = UInt(dto.top_p),
+            n = UInt(dto.n),
+            stream = UBool(dto.stream),
+            stop = None if dto.stop is None else UStr(dto.stop),
+            max_tokens = UInt(dto.max_tokens),
+            presence_penalty = UFloat(dto.presence_penalty),
+            frequency_penalty = UFloat(dto.frequency_penalty),
+            logit_bias = UDict(dto.logit_bias),
+            user = UStr(dto.user)
+        )
+    def to_dto(self, x:OpenaiChatInput):
+        return OpenaiChatInputDTO(
+            messages = [openai_chat_message_assembler.to_dto(m) for m in x.messages],
+            model = x.model.get_value(),
+            temperature = x.temperature.get_value(),
+            top_p = x.top_p.get_value(),
+            n = x.n.get_value(),
+            stream = x.stream.get_value(),
+            stop = None if x.stop is None else x.stop.get_value(),
+            max_tokens = x.max_tokens.get_value(),
+            presence_penalty = x.presence_penalty.get_value(),
+            frequency_penalty = x.frequency_penalty.get_value(),
+            logit_bias = x.logit_bias.get_value(),
+            user = x.user.get_value()
+        )
+openai_chat_input_assembler=OpenaiChatInputAssembler()
+
+
+
+class OpenaiChatUsageAssembler(Assembler):
+    def to_entity(self, dto: OpenaiChatUsageDTO):
+        return OpenaiChatUsage(
+            prompt_tokens = UInt(dto.prompt_tokens),
+            completion_tokens = UInt(dto.completion_tokens),
+            total_tokens = UInt(dto.total_tokens)
+        )
+    def to_dto(self, x:OpenaiChatUsage):
+        return OpenaiChatUsageDTO(
+            prompt_tokens = x.prompt_tokens.get_value(),
+            completion_tokens = x.completion_tokens.get_value(),
+            total_tokens = x.total_tokens.get_value()
+        )
+openai_chat_usage_assembler=OpenaiChatUsageAssembler()
+
+
+
+class OpenaiChatChoiceAssembler(Assembler):
+    def to_entity(self, dto: OpenaiChatChoiceDTO):
+        return OpenaiChatChoice(
+            message = openai_chat_message_assembler.to_entity(dto.message),
+            finish_reason = None if dto.finish_reason is None else UStr(dto.finish_reason),
+            index = UInt(dto.index)
+        )
+    def to_dto(self, x:OpenaiChatChoice):
+        return OpenaiChatChoiceDTO(
+            message = openai_chat_message_assembler.to_dto(x.message),
+            finish_reason = None if x.finish_reason is None else x.finish_reason.get_value(),
+            index = x.index.get_value()
+        )
+openai_chat_choice_assembler=OpenaiChatChoiceAssembler()
+
+
+
+class OpenaiChatOutputAssembler(Assembler):
+    def to_entity(self, dto: OpenaiChatOutputDTO):
+        return OpenaiChatOutput(
+            id = UStr(dto.id),
+            object = UStr(dto.object),
+            created = UStr(dto.created),
+            model = UStr(dto.model),
+            usage = openai_chat_usage_assembler.to_entity(dto.usage),
+            choices = [openai_chat_choice_assembler.to_entity(m) for m in dto.choices]
+        )
+    def to_dto(self, x:OpenaiChatOutput):
+        return OpenaiChatOutputDTO(
+            id = x.id.get_value(),
+            object = x.object.get_value(),
+            created = x.created.get_value(),
+            model = x.model.get_value(),
+            usage = openai_chat_usage_assembler.to_dto(x.usage),
+            choices = [openai_chat_choice_assembler.to_dto(m) for m in x.choices]
+        )
+openai_chat_output_assembler=OpenaiChatOutputAssembler()
+
+
+
+class OpenaiRequestAssembler(Assembler):
+    def to_entity(self, dto: OpenaiRequestDTO):
+        return OpenaiRequest(
+            input = openai_chat_input_assembler.to_entity(dto.input),
+            limit = UInt(dto.limit),
+            timeout = UInt(dto.timeout),
+            request_id = None if dto.request_id is None else UStr(dto.request_id),
+            others = None if dto.others is None else UDict(dto.others)
+        )
+    def to_dto(self, x:OpenaiRequest):
+        return OpenaiRequestDTO(
+            input = openai_chat_input_assembler.to_dto(x.input),
+            limit = x.limit.get_value(),
+            timeout = x.timeout.get_value(),
+            request_id = None if x.request_id is None else x.request_id.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+openai_request_assembler=OpenaiRequestAssembler()
+
+
+
+class OpenaiResponseAssembler(Assembler):
+    def to_entity(self, dto: OpenaiResponseDTO):
+        return OpenaiResponse(
+            status = Status(dto.status),
+            exception = None if dto.exception is None else UStr(dto.exception),
+            result = None if dto.result is None else UDict(dto.result),
+            others = None if dto.others is None else UDict(dto.others)
+        )
+    def to_dto(self, x:OpenaiResponse):
+        return OpenaiResponseDTO(
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            result = None if x.result is None else x.result.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+openai_response_assembler=OpenaiResponseAssembler()
+
+
+
+class OpenaiItemAssembler(Assembler):
+    def to_entity(self, dto: OpenaiItemDTO):
+        return OpenaiItem(
+            item_id = UStr(dto.item_id),
+            status = Status(dto.status),
+            exception = None if dto.exception is None else UStr(dto.exception),
+            request = None if dto.request is None else search_request_assembler.to_entity(dto.request),
+            response = None if dto.response is None else search_response_assembler.to_entity(dto.response),
+            entry_time = None if dto.entry_time is None else UDate(dto.entry_time),
+            exit_time = None if dto.exit_time is None else UDate(dto.exit_time),
+            create_time = None if dto.create_time is None else UDate(dto.create_time),
+            failure_times = UInt(dto.failure_times)
+        )
+    def to_dto(self, x:OpenaiItem):
+        return OpenaiItemDTO(
+            item_id = x.item_id.get_value(),
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            request = None if x.request is None else search_request_assembler.to_dto(x.request),
+            response = None if x.response is None else search_response_assembler.to_dto(x.response),
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            create_time = None if x.create_time is None else x.create_time.get_value(),
+            failure_times = x.failure_times.get_value()
+        )
+openai_item_assembler=OpenaiItemAssembler()
