@@ -17,6 +17,14 @@ from .entity import (
     InstanceInfo,
     InstanceUserSetting,
     NodeInventory,
+    OpenaiChatChoice,
+    OpenaiChatInput,
+    OpenaiChatMessage,
+    OpenaiChatOutput,
+    OpenaiChatUsage,
+    OpenaiItem,
+    OpenaiRequest,
+    OpenaiResponse,
     ProxyInfo,
     RandomTemplateVariables,
     RecoverSetting,
@@ -45,6 +53,14 @@ from .do import (
     InstanceInfoDO,
     InstanceUserSettingDO,
     NodeInventoryDO,
+    OpenaiChatChoiceDO,
+    OpenaiChatInputDO,
+    OpenaiChatMessageDO,
+    OpenaiChatOutputDO,
+    OpenaiChatUsageDO,
+    OpenaiItemDO,
+    OpenaiRequestDO,
+    OpenaiResponseDO,
     ProxyInfoDO,
     RandomTemplateVariablesDO,
     RecoverSettingDO,
@@ -674,3 +690,179 @@ class InstanceCreationItemConverter(Converter):
             _life_time = x._life_time.get_value()
         )
 instance_creation_item_converter=InstanceCreationItemConverter()
+
+
+
+class OpenaiChatMessageConverter(Converter):
+    def to_entity(self, do: OpenaiChatMessageDO):
+        return OpenaiChatMessage(
+            content = UStr(do.content),
+            role = UStr(do.role)
+        )
+    def to_do(self, x:OpenaiChatMessage):
+        return OpenaiChatMessageDO(
+            content = x.content.get_value(),
+            role = x.role.get_value()
+        )
+openai_chat_message_converter=OpenaiChatMessageConverter()
+
+
+
+class OpenaiChatInputConverter(Converter):
+    def to_entity(self, do: OpenaiChatInputDO):
+        return OpenaiChatInput(
+            messages = [openai_chat_message_converter.to_entity(m) for m in do.messages],
+            model = UStr(do.model),
+            temperature = UInt(do.temperature),
+            top_p = UInt(do.top_p),
+            n = UInt(do.n),
+            stream = UBool(do.stream),
+            stop = None if do.stop is None else UStr(do.stop),
+            max_tokens = UInt(do.max_tokens),
+            presence_penalty = UFloat(do.presence_penalty),
+            frequency_penalty = UFloat(do.frequency_penalty),
+            logit_bias = UDict(do.logit_bias),
+            user = UStr(do.user)
+        )
+    def to_do(self, x:OpenaiChatInput):
+        return OpenaiChatInputDO(
+            messages = [openai_chat_message_converter.to_do(m) for m in x.messages],
+            model = x.model.get_value(),
+            temperature = x.temperature.get_value(),
+            top_p = x.top_p.get_value(),
+            n = x.n.get_value(),
+            stream = x.stream.get_value(),
+            stop = None if x.stop is None else x.stop.get_value(),
+            max_tokens = x.max_tokens.get_value(),
+            presence_penalty = x.presence_penalty.get_value(),
+            frequency_penalty = x.frequency_penalty.get_value(),
+            logit_bias = x.logit_bias.get_value(),
+            user = x.user.get_value()
+        )
+openai_chat_input_converter=OpenaiChatInputConverter()
+
+
+
+class OpenaiChatUsageConverter(Converter):
+    def to_entity(self, do: OpenaiChatUsageDO):
+        return OpenaiChatUsage(
+            prompt_tokens = UInt(do.prompt_tokens),
+            completion_tokens = UInt(do.completion_tokens),
+            total_tokens = UInt(do.total_tokens)
+        )
+    def to_do(self, x:OpenaiChatUsage):
+        return OpenaiChatUsageDO(
+            prompt_tokens = x.prompt_tokens.get_value(),
+            completion_tokens = x.completion_tokens.get_value(),
+            total_tokens = x.total_tokens.get_value()
+        )
+openai_chat_usage_converter=OpenaiChatUsageConverter()
+
+
+
+class OpenaiChatChoiceConverter(Converter):
+    def to_entity(self, do: OpenaiChatChoiceDO):
+        return OpenaiChatChoice(
+            message = openai_chat_message_converter.to_entity(do.message),
+            finish_reason = None if do.finish_reason is None else UStr(do.finish_reason),
+            index = UInt(do.index)
+        )
+    def to_do(self, x:OpenaiChatChoice):
+        return OpenaiChatChoiceDO(
+            message = openai_chat_message_converter.to_do(x.message),
+            finish_reason = None if x.finish_reason is None else x.finish_reason.get_value(),
+            index = x.index.get_value()
+        )
+openai_chat_choice_converter=OpenaiChatChoiceConverter()
+
+
+
+class OpenaiChatOutputConverter(Converter):
+    def to_entity(self, do: OpenaiChatOutputDO):
+        return OpenaiChatOutput(
+            id = UStr(do.id),
+            object = UStr(do.object),
+            created = UStr(do.created),
+            model = UStr(do.model),
+            usage = openai_chat_usage_converter.to_entity(do.usage),
+            choices = [openai_chat_choice_converter.to_entity(m) for m in do.choices]
+        )
+    def to_do(self, x:OpenaiChatOutput):
+        return OpenaiChatOutputDO(
+            id = x.id.get_value(),
+            object = x.object.get_value(),
+            created = x.created.get_value(),
+            model = x.model.get_value(),
+            usage = openai_chat_usage_converter.to_do(x.usage),
+            choices = [openai_chat_choice_converter.to_do(m) for m in x.choices]
+        )
+openai_chat_output_converter=OpenaiChatOutputConverter()
+
+
+
+class OpenaiRequestConverter(Converter):
+    def to_entity(self, do: OpenaiRequestDO):
+        return OpenaiRequest(
+            input = openai_chat_input_converter.to_entity(do.input),
+            limit = UInt(do.limit),
+            timeout = UInt(do.timeout),
+            request_id = None if do.request_id is None else UStr(do.request_id),
+            others = None if do.others is None else UDict(do.others)
+        )
+    def to_do(self, x:OpenaiRequest):
+        return OpenaiRequestDO(
+            input = openai_chat_input_converter.to_do(x.input),
+            limit = x.limit.get_value(),
+            timeout = x.timeout.get_value(),
+            request_id = None if x.request_id is None else x.request_id.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+openai_request_converter=OpenaiRequestConverter()
+
+
+
+class OpenaiResponseConverter(Converter):
+    def to_entity(self, do: OpenaiResponseDO):
+        return OpenaiResponse(
+            status = Status(do.status),
+            exception = None if do.exception is None else UStr(do.exception),
+            result = None if do.result is None else UDict(do.result),
+            others = None if do.others is None else UDict(do.others)
+        )
+    def to_do(self, x:OpenaiResponse):
+        return OpenaiResponseDO(
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            result = None if x.result is None else x.result.get_value(),
+            others = None if x.others is None else x.others.get_value()
+        )
+openai_response_converter=OpenaiResponseConverter()
+
+
+
+class OpenaiItemConverter(Converter):
+    def to_entity(self, do: OpenaiItemDO):
+        return OpenaiItem(
+            item_id = UStr(do.item_id),
+            status = Status(do.status),
+            exception = None if do.exception is None else UStr(do.exception),
+            request = None if do.request is None else search_request_converter.to_entity(do.request),
+            response = None if do.response is None else search_response_converter.to_entity(do.response),
+            entry_time = None if do.entry_time is None else UDate(do.entry_time),
+            exit_time = None if do.exit_time is None else UDate(do.exit_time),
+            create_time = None if do.create_time is None else UDate(do.create_time),
+            failure_times = UInt(do.failure_times)
+        )
+    def to_do(self, x:OpenaiItem):
+        return OpenaiItemDO(
+            item_id = x.item_id.get_value(),
+            status = x.status.get_value(),
+            exception = None if x.exception is None else x.exception.get_value(),
+            request = None if x.request is None else search_request_converter.to_do(x.request),
+            response = None if x.response is None else search_response_converter.to_do(x.response),
+            entry_time = None if x.entry_time is None else x.entry_time.get_value(),
+            exit_time = None if x.exit_time is None else x.exit_time.get_value(),
+            create_time = None if x.create_time is None else x.create_time.get_value(),
+            failure_times = x.failure_times.get_value()
+        )
+openai_item_converter=OpenaiItemConverter()
