@@ -265,4 +265,80 @@ class InstanceCreationItemDTO(BaseModel):
     entry_time: Optional[datetime.datetime] = None
     exit_time: Optional[datetime.datetime] = None
     exception: Optional[str] = None
-    _life_time: str = 86400
\ No newline at end of file
+    _life_time: str = 86400
+
+
+
+class OpenaiChatMessageDTO(BaseModel):
+    content: str
+    role: str = 'user'
+
+
+
+class OpenaiChatInputDTO(BaseModel):
+    messages: List[OpenaiChatMessageDTO]
+    model: str = 'gpt-3.5-turbo'
+    temperature: int = 1
+    top_p: int = 1
+    n: int = 1
+    stream: bool = False
+    stop: Optional[str] = None
+    max_tokens: int = 4000
+    presence_penalty: float = 0
+    frequency_penalty: float = 0
+    logit_bias: dict = {}
+    user: str = 'test'
+
+
+
+class OpenaiChatUsageDTO(BaseModel):
+    prompt_tokens: int
+    completion_tokens: int
+    total_tokens: int
+
+
+
+class OpenaiChatChoiceDTO(BaseModel):
+    message: OpenaiChatMessageDTO
+    finish_reason: Optional[str]
+    index: int
+
+
+
+class OpenaiChatOutputDTO(BaseModel):
+    id: str
+    object: str
+    created: str
+    model: str
+    usage: OpenaiChatUsageDTO
+    choices: List[OpenaiChatChoiceDTO]
+
+
+
+class OpenaiRequestDTO(BaseModel):
+    input: OpenaiChatInputDTO
+    limit: int = 5
+    timeout: int = 300
+    request_id: Optional[str] = None
+    others: Optional[dict] = None
+
+
+
+class OpenaiResponseDTO(BaseModel):
+    status: str
+    exception: Optional[str] = None
+    result: Optional[dict] = None
+    others: Optional[dict] = None
+
+
+
+class OpenaiItemDTO(BaseModel):
+    item_id: str
+    status: str
+    exception: Optional[str] = None
+    request: Optional[SearchRequestDTO] = None
+    response: Optional[SearchResponseDTO] = None
+    entry_time: Optional[datetime.datetime] = None
+    exit_time: Optional[datetime.datetime] = None
+    create_time: Optional[datetime.datetime] = None
+    failure_times: int = 0
\ No newline at end of file
