@@ -670,4 +670,196 @@ class InstanceCreationItem(Entity):
         self.entry_time = entry_time
         self.exit_time = exit_time
         self.exception = exception
-        self._life_time = _life_time
\ No newline at end of file
+        self._life_time = _life_time
+
+
+
+class OpenaiChatMessage(Entity):
+    def __init__(
+        self,
+        content: UStr,
+        role: UStr = UStr('user'),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.content = content
+        self.role = role
+
+
+
+class OpenaiChatInput(Entity):
+    def __init__(
+        self,
+        messages: List[OpenaiChatMessage],
+        model: UStr = UStr('gpt-3.5-turbo'),
+        temperature: UInt = UInt(1),
+        top_p: UInt = UInt(1),
+        n: UInt = UInt(1),
+        stream: UBool = UBool(False),
+        stop: Optional[UStr] = None,
+        max_tokens: UInt = UInt(4000),
+        presence_penalty: UFloat = UFloat(0),
+        frequency_penalty: UFloat = UFloat(0),
+        logit_bias: UDict = UDict({}),
+        user: UStr = UStr('test'),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.messages = messages
+        self.model = model
+        self.temperature = temperature
+        self.top_p = top_p
+        self.n = n
+        self.stream = stream
+        self.stop = stop
+        self.max_tokens = max_tokens
+        self.presence_penalty = presence_penalty
+        self.frequency_penalty = frequency_penalty
+        self.logit_bias = logit_bias
+        self.user = user
+
+
+
+class OpenaiChatUsage(Entity):
+    def __init__(
+        self,
+        prompt_tokens: UInt,
+        completion_tokens: UInt,
+        total_tokens: UInt,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.prompt_tokens = prompt_tokens
+        self.completion_tokens = completion_tokens
+        self.total_tokens = total_tokens
+
+
+
+class OpenaiChatChoice(Entity):
+    def __init__(
+        self,
+        message: OpenaiChatMessage,
+        finish_reason: Optional[UStr],
+        index: UInt,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.message = message
+        self.finish_reason = finish_reason
+        self.index = index
+
+
+
+class OpenaiChatOutput(Entity):
+    def __init__(
+        self,
+        id: UStr,
+        object: UStr,
+        created: UStr,
+        model: UStr,
+        usage: OpenaiChatUsage,
+        choices: List[OpenaiChatChoice],
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.id = id
+        self.object = object
+        self.created = created
+        self.model = model
+        self.usage = usage
+        self.choices = choices
+
+
+
+class OpenaiRequest(Entity):
+    def __init__(
+        self,
+        input: OpenaiChatInput,
+        limit: UInt = UInt(5),
+        timeout: UInt = UInt(300),
+        request_id: Optional[UStr] = None,
+        others: Optional[UDict] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.input = input
+        self.limit = limit
+        self.timeout = timeout
+        self.request_id = request_id
+        self.others = others
+
+
+
+class OpenaiResponse(Entity):
+    def __init__(
+        self,
+        status: Status,
+        exception: Optional[UStr] = None,
+        result: Optional[UDict] = None,
+        others: Optional[UDict] = None,
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.status = status
+        self.exception = exception
+        self.result = result
+        self.others = others
+
+
+
+class OpenaiItem(Entity):
+    def __init__(
+        self,
+        item_id: UStr,
+        status: Status,
+        exception: Optional[UStr] = None,
+        request: Optional[SearchRequest] = None,
+        response: Optional[SearchResponse] = None,
+        entry_time: Optional[UDate] = None,
+        exit_time: Optional[UDate] = None,
+        create_time: Optional[UDate] = None,
+        failure_times: UInt = UInt(0),
+        **kwargs
+    ) -> None:
+        all_args=locals()
+        del all_args['self']
+        del all_args['__class__']
+        del all_args['kwargs']
+        super().__init__(**all_args)
+        self.item_id = item_id
+        self.status = status
+        self.exception = exception
+        self.request = request
+        self.response = response
+        self.entry_time = entry_time
+        self.exit_time = exit_time
+        self.create_time = create_time
+        self.failure_times = failure_times
\ No newline at end of file
