@@ -24,14 +24,26 @@ def __fill_class(model_json, model_class):
 
 
 def serialize(model):
-    s = str(b64encode(model.json().encode()))
+    if isinstance(model, list):
+        model = [m.json().encode() for m in model]
+        model = b'7SQXZMcEC*W7yOgv'.join(model)
+        s = str(b64encode(model))
+    else:
+        s = str(b64encode(model.json().encode()))
     return s[2:-1]
 
 
 
 def deserialize(s, model_class=None):
     s = f"b'{s}'"
-    model_json = json.loads(b64decode(eval(s)))
-    if model_class:
+    model_byte = b64decode(eval(s))
+    model_byte_list = model_byte.split(b'7SQXZMcEC*W7yOgv')
+    if len(model_byte_list)>1:
+        model_json = [json.loads(m) for m in model_byte_list]
+    else:
+        model_json = json.loads(model_byte_list[0])
+    if model_class and isinstance(model_json, list):
+        return [__fill_class(m, model_class) for m in model_json]
+    elif model_class:
         return __fill_class(model_json, model_class)
     return model_json
\ No newline at end of file
